@@ -19,6 +19,7 @@ pub(crate) mod non_critical_lints {
     pub mod no_alert;
     pub mod no_console;
     pub mod no_debugger;
+    pub mod no_empty_pattern;
     pub mod no_use_before_define;
     pub mod prefer_regex_literals;
     pub mod quotes;
@@ -85,6 +86,10 @@ pub fn all(lint_params: LintParams) -> Vec<Box<dyn Rule>> {
             &lint_config.dot_notation,
         ));
 
+        rules.extend(no_empty_pattern::no_empty_pattern(
+            &lint_config.no_empty_pattern,
+        ));
+
         rules.extend(eqeqeq::eqeqeq(&lint_config.eqeqeq));
     }
 
